@@ -25,7 +25,7 @@
 #include "nautilus-menu.h"
 #include "nautilus-extension-i18n.h"
 
-#include <glib/glist.h>
+#include <glib.h>
 
 #define NAUTILUS_MENU_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), NAUTILUS_TYPE_MENU, NautilusMenuPrivate))
 
