@@ -30,12 +30,18 @@
 #include <string.h>
 #include <time.h>
 #include <unistd.h>
-#include "nautilus-file.h"
+#include <sys/stat.h>
+
+#include <glib.h>
+#include <glib/gstdio.h>
+#include <glib/gi18n.h>
+#include <gtk/gtk.h>
+
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-stock-dialogs.h>
-#include <glib/gi18n.h>
-#include <gtk/gtk.h>
+
+#include "nautilus-file.h"
 #include "nautilus-emblem-utils.h"
 
 #define EMBLEM_NAME_TRASH   "emblem-trash"
@@ -43,6 +49,7 @@
 #define EMBLEM_NAME_NOREAD  "emblem-noread"
 #define EMBLEM_NAME_NOWRITE "emblem-nowrite"
 #define EMBLEM_NAME_NOTE    "emblem-note"
+#define EMBLEM_NAME_SHARED  "emblem-shared"
 
 GList *
 nautilus_emblem_list_available (void)
@@ -97,6 +104,9 @@ is_reserved_keyword (const char *keyword)
 	if (g_ascii_strcasecmp (keyword, NAUTILUS_FILE_EMBLEM_NAME_NOTE) == 0) {
 		return TRUE;
 	}
+	if (g_ascii_strcasecmp (keyword, NAUTILUS_FILE_EMBLEM_NAME_SHARED) == 0) {
+		return TRUE;
+	}
 
 	available = nautilus_emblem_list_available ();
 	icon_name = nautilus_emblem_get_icon_name_from_keyword (keyword);
@@ -127,6 +137,9 @@ nautilus_emblem_should_show_in_list (const char *emblem)
 	if (strcmp (emblem, EMBLEM_NAME_NOTE) == 0) {
 		return FALSE;
 	}
+	if (strcmp (emblem, EMBLEM_NAME_SHARED) == 0) {
+		return FALSE;
+	}
 
 	return TRUE;
 }
@@ -294,7 +307,7 @@ nautilus_emblem_install_custom_emblem (GdkPixbuf *pixbuf,
 	}
 
 	/* Touch the toplevel dir */
-	if (stat (stat_dir, &stat_buf) == 0) {
+	if (g_stat (stat_dir, &stat_buf) == 0) {
 		ubuf.actime = stat_buf.st_atime;
 		ubuf.modtime = time (NULL);
 		utime (stat_dir, &ubuf);
@@ -315,7 +328,7 @@ nautilus_emblem_can_remove_emblem (const char *keyword)
 	path = g_strdup_printf ("%s/.icons/hicolor/48x48/emblems/emblem-%s.png",
 				g_get_home_dir (), keyword);
 
-	if (access (path, F_OK|W_OK) != 0) {
+	if (g_access (path, F_OK|W_OK) != 0) {
 		ret = FALSE;
 	}
 
